@@ -3,7 +3,7 @@ package Log::ger::Plugin::MultilevelLog;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-07'; # DATE
 our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.032'; # VERSION
+our $VERSION = '0.033'; # VERSION
 
 use strict;
 use warnings;
@@ -71,8 +71,8 @@ sub get_hooks {
             sub {        # hook
                 my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
                 return [{
-                    log_subs    => [[$sub_name   , undef, 'ml', undef, 'ml']],
-                    log_methods => [[$method_name, undef, 'ml', undef, 'ml']],
+                    logger_subs    => [[$sub_name   , undef, 'ml', undef, 'ml']],
+                    logger_methods => [[$method_name, undef, 'ml', undef, 'ml']],
                 }, $conf{exclusive}];
             },
         ],
@@ -94,7 +94,7 @@ Log::ger::Plugin::MultilevelLog - Create a log($LEVEL, ...) subroutine/method
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
